publicsuffix_gleam/suffix_list
Types
The suffix list data structure
pub opaque type SuffixList
Values
pub fn find_suffix(
host: String,
suffix_list: SuffixList,
) -> Result(String, Nil)
Find the matching public suffix for a hostname
pub fn load(include_private: Bool) -> SuffixList
Load the public suffix list from the data file
pub fn parse(
content: String,
include_private: Bool,
) -> SuffixList
Parse the public suffix list content into a SuffixList